# Interpolating Normal Splines 

Consider the following interpolation problem:

*Problem:* Given points ``x_1 \lt  x_2 \lt \dots \lt x_{n_1}``, ``s_1 \lt s_2 \lt \dots \lt s_{n_2}`` and  ``t_1 \lt t_2 \lt \dots \lt t_{n_3}`` find a function ``f`` such that

```math
\tag{1}
\begin{aligned}
& f(x_i) =  u_i \, , \quad  i = 1, 2, \dots, n_1 \, ,
\\  
& f'(s_j) =  v_j \, , \quad  j = 1, 2, \dots, n_2 \, ,
\\  
& f''(t_k) =  w_k \, , \quad  k = 1, 2, \dots, n_3 \, ,
\\
& n_1 \gt 0 \, ,  \ \  n_2 \ge 0 \, , \ \  n_3 \ge 0 \, .
\end{aligned}
``` 
Note that knots ``\{x_i\}``, ``\{s_j\}`` and ``\{t_k\}`` may coincide.

We assume that function ``f`` is an element of Hilbert space ``H = H(X)`` over a set ``X`` (where ``X`` is ``R`` or an interval from ``R``) and Hilbert space is selected in a such way that it is continuously embedded in space ``C^2(X)`` of functions continuous with their second derivatives, therefore functionals ``F_i``, ``F'_j``, and ``F''_k``

```math
\begin{aligned}
  & F_i(\varphi) = \varphi (x_i) \, , \ \ F'_j(\varphi) = \varphi' (s_j) \, , \ \  F''_k(\varphi) = \varphi''(t_k) \, ,  \ \forall \varphi \in H \, , 
   \\
  & x_i, \, s_j, \, t_k \in X \, , 
   \\
  & i = 1, 2, \dots, n_1 \, , \ \   j = 1, 2, \dots, n_2 \, ,  \ \  k = 1, 2, \dots, n_3 \, .
\end{aligned}
```
are linear continuous functionals in ``H``. It is obvious that all these functionals are linear independent. In accordance with Riesz representation theorem [1] these linear continuous functionals can be represented in the form of inner product of some elements ``h_i, h'_j, h''_k \in H`` and ``\varphi \in H``, for any ``\varphi \in H``:

```math
 f(x_i) =  F_i(\varphi) = {\langle h_i,  \varphi \rangle}_H \, ,  \quad  F'_j(\varphi) = {\langle h'_j,  \varphi \rangle}_H  \, , \quad  F''_k(\varphi) = {\langle h''_k,  \varphi \rangle}_H \, ,
   \quad     \forall \varphi \in H \, , 
\\  i = 1, 2, \dots, n_1 \, , \ \  j = 1, 2, \dots, n_2 \, ,  \ \ k = 1, 2, \dots, n_3 \, .
```
Elements ``h_i, h'_j`` and ``h''_k`` are twice continuously differentiable functions. Thereby the original system of constraints (1) can be written in form:

```math
\tag{2}
\begin{aligned}
& f(x_i) = F_i(f) = {\langle h_i,  f \rangle}_H  = u_i \, ,
\\
 & f'(s_j) = F'_j(f) = {\langle h'_j,  f \rangle}_H = v_j \, ,  
 \\
 & f''(t_k) = F''_k(f) = {\langle h''_k,  f \rangle}_H = w_k\, ,
 \\
 &  f \in H \, , 
 \\
 & i = 1, 2, \dots, n_1 \, , \ \  j = 1, 2, \dots, n_2 \, , 
 \ \ k = 1, 2, \dots, n_3 \, ,
\end{aligned}
```
here all functions ``h_i, h'_j, h''_k \in H`` are linear independent and system of constrains (2) defines a nonempty convex and closed set (as an intersection of hyper-planes in the Hilbert space ``H``).

Problem of reconstruction of function ``f`` satisfying system of constraints (2) is undetermined. We reformulate it as a problem of finding solution of this system of constraints that has minimal norm:

```math
\tag{3}
   \sigma = {\rm arg\,min}\{  \| f - z \|^2_H : (2), z \in H, \forall f \in H \} \, ,
```
where ``z \in H`` is a "prototype" function. Solution of this problem exists and it is unique ([6], [16]) as a projection of element ``z`` on the nonempty convex closed set in Hilbert space ``H``. Element ``\sigma`` is an interpolating normal spline.

In accordance with generalized Lagrange method ([13], [16]) solution of the problem (3) can be presented as:

```math
\tag{4}
\sigma =  z + \sum _{i=1}^{n_1} \mu_i  h_i  + \sum _{j=1}^{n_2} \mu'_j  h'_j  + \sum _{k=1}^{n_3} \mu''_k  h''_k \ ,
```
where coefficients ``\mu_i``, ``\mu'_j`` and ``\mu''_k`` are defined by system of linear equations

```math
\tag{5}
    \sum _{l=1}^{n_1} g_{il} \mu_l + \sum _{j=1}^{n_2} g'_{ij} \mu'_j  + \sum _{k=1}^{n_3} g''_{ik} \mu''_k  =  u_i - {\langle h_i,  z \rangle}_H \, , \quad 1 \le i \le n_1 \, , \\      \sum _{i=1}^{n_1} g'_{ij} \mu_i + \sum _{l=1}^{n_2} g''_{jl} \mu'_l  + \sum _{k=1}^{n_3} g'''_{jk} \mu''_k  =  v_j - {\langle h'_j,  z \rangle}_H  \, , \quad 1 \le j \le n_2 \, ,  \\      \sum _{i=1}^{n_1} g''_{ik} \mu_i + \sum _{j=1}^{n_2} g'''_{jk} \mu'_j  + \sum _{l=1}^{n_3} g^{\rm iv}_{kl} \mu''_l  =  w_k - {\langle h''_k,  z \rangle}_H  \, , \quad 1 \le k \le n_3 \, ,
```
Matrix of system (5) is the positive definite symmetric Gram matrix of the set of linearly independent elements  ``\{h_i\}, \{h'_j\}``, ``\{h''_k\}``, and coefficients ``g_{il}, g'_{ij}, g''_{ik}, g''_{jl}, g'''_{jk}, g^{\rm iv}_{kl}`` are defined as follows:

```math
\tag{6}
   g_{il} = {\langle h_i,  h_l \rangle}_H \, , \ \ g'_{ij} = {\langle h_i,  h'_j \rangle}_H \, , \ \ g''_{ik} = {\langle h_i,  h''_k \rangle}_H 
   \\
   \quad  g''_{jl} = {\langle h'_j,  h'_l \rangle}_H \, , \ \ g'''_{jk} = {\langle h'_j,  h''_k \rangle}_H \, , \ \ g^{\rm iv}_{kl} = {\langle h''_k,  h''_l \rangle}_H \, .
```

Let ``H = H(X)`` be a reproducing kernel Hilbert space with reproducing kernel ``V(\eta, \xi)``. Recall the definition of the reproducing kernel ([4], [7]). The reproducing kernel is a such function ``V(\eta, \xi)`` that

* for every ``\xi \in X``, ``\ V(\eta, \xi)`` as function of ``\eta`` belongs to ``H``
* for every ``\xi \in X`` and every function ``\varphi \in H``

```math
\tag{7}
\varphi(\xi) = {\langle V(\eta, \xi),  \varphi(\eta) \rangle}_H
```
Reproducing kernel is a symmetric function:

```math
V(\eta, \xi) = V(\xi, \eta) \, ,
```
also, in the considered here case it is twice continuously differentiable function by ``\xi`` and by ``\eta``. Differentiating the identity (7) allows to get the identities for derivatives:

```math
\tag{8}
\frac {d \varphi(\xi)}{d \xi} = {\left \langle \frac{\partial V(\cdot, \xi)} {\partial \xi}, \varphi \right \rangle}_H , \quad \frac {d^2 \varphi(\xi)}{d \xi^2} = {\left \langle \frac{\partial^2 V(\cdot, \xi)} {\partial \xi^2}, \varphi \right \rangle}_H  .
``` 
Now it is possible to express functions ``h_i, h'_j, h''_k`` via the reproducing kernel ``V``. Comparing (2) with (7) and (8) we receive:

```math
\tag{9}
   h_i (\eta) =  V(\eta, x_i) \, ,  \qquad  i = 1, 2, \dots, n_1 \, \\  
   h'_j (\eta) =  \frac{\partial V(\eta, s_j)}{\partial \xi}  \, , \quad  j = 1, 2, \dots, n_2 \ , \\  
   h''_k (\eta) =  \frac{\partial^2 V(\eta, t_k)}{\partial \xi^2}  \, , \ \  k = 1, 2, \dots, n_3 \ .
``` 
The coefficients (6) of the Gram matrix can be presented as ([7], [8], [10]):

```math
\tag{10}
\begin{aligned}
   & g_{il} = {\langle h_i,  h_l \rangle}_H = {\langle V(\cdot, x_i),  V(\cdot, x_l) \rangle}_H = V(x_i, x_l) \, , 
   \\
    & g'_{ij} = {\langle h_i,  h'_j \rangle}_H = {\left \langle V(\cdot, x_i), \frac{\partial V(\cdot, s_j)}{\partial \xi} \right \rangle}_H =  \frac{\partial V(x_i, s_j)}{\partial \xi}\,  , 
    \\
    & g''_{ik} = {\langle h_i,  h''_k \rangle}_H = {\left \langle V(\cdot, x_i), \frac{\partial^2 V(\cdot, t_k)}{\partial \xi^2} \right \rangle}_H =  \frac{\partial^2 V(x_i, t_k)}{\partial \xi^2}  \, .
\end{aligned}
``` 
With the help of (7) and (10), we can also calculate ``g''_{jl}`` ([8], [10]):

```math
\tag{11}
\begin{aligned}
& g''_{jl} = {\langle h'_j,  h'_l \rangle}_H  =  {\left \langle \frac{\partial V(\cdot, s_j)}{\partial \xi}, \frac{\partial V(\cdot, s_l)}{\partial \xi} \right \rangle}_H = 
\\
 & \left . \frac {d} {d \xi} {\left \langle V(\cdot, \xi), \frac{\partial V(\cdot, s_l)}{\partial \xi} \right \rangle}_H \right \vert_{\xi = s_j} = 
 \\
 & \left . \frac {d} {d \xi} \left ( \frac{\partial V(\xi, s_l)} {\partial \xi} \right ) \right \vert_{\xi = s_j} = \ \ \ \frac {\partial^2 V(s_j, s_l)} {\partial \eta \partial \xi} \, .
\end{aligned}
``` 
Further

```math
\tag{12}
g'''_{jk} = {\langle h'_j,  h''_k \rangle}_H  =  \frac {\partial^3 V(s_j, t_k)} {\partial \eta \partial \xi^2} \, , \\ g^{\rm iv}_{kl} = {\langle h''_k,  h''_l \rangle}_H  =  \frac {\partial^4 V(t_k, t_l)}{\partial \eta^2 \partial \xi^2}  \, ,
``` 
 and

```math
\tag{13}
\begin{aligned}
  & {\langle h_i,  z \rangle}_H  =  {\langle V(\cdot, x_i),  z \rangle}_H  = z(x_i)  \, , 
  \\
  & {\langle h'_j,  z \rangle}_H  =  z'(s_j) \, , 
  \\
 & {\langle h''_k,  z \rangle}_H  =  z''(t_k) \, .
\end{aligned}
``` 

Normal splines will be constructed in Sobolev space ``W^3_2 [a, b]`` and in Bessel potential space ``H^3_\varepsilon (R)`` (See [1, 2, 4, 20] for details). Elements of these spaces can be treated as twice continuously differentiable functions.

Reproducing kernel for Sobolev spaces ``W^l_2 [0,1]`` (here ``l`` — any positive integer) was constructed in work [8]. Thus, reproducing kernel for Sobolev space ``W^3_2 [0, 1]`` with norm

```math
\| f \|_{W_2^3} = \left ( \sum_{i=0}^2 (f^{(i)}(0))^2 + \int_0^1 (f^{(3)}(s))^2 ds \right )^{1/2} \, ,
```
can be presented as

```math
V(\eta, \xi) =
  \begin{cases}
       \sum_{i=0}^2 \frac{\xi^i}{!i} \left ( \frac{\eta^i}{!i} + (-1)^{i} \frac {\eta^{5 - i}}{(5 - i)!}  \right )  \,  , &  0 \le \eta \le \xi \le 1
        \\
       \sum_{i=0}^2 \frac{\eta^i}{!i} \left ( \frac{\xi^i}{!i} + (-1)^{i} \frac {\xi^{5 - i}}{(5 - i)!}  \right ) \,  , &  0 \le \xi \le \eta \le 1   \end{cases}
```
or

```math
\tag{14}
V(\eta, \xi) =
  \begin{cases}
       1 + \eta \xi + \frac{(\eta^5 - 5 \eta^4 \xi + 10 \eta^3 \xi^2 + 30 \eta^2 \xi^2 )}{120}  \,  , &  0 \le \eta \le \xi \le 1 \\
       1 + \eta \xi + \frac{(\xi^5 - 5 \xi^4 \eta + 10 \xi^3 \eta^2 + 30 \xi^2 \eta^2 )}{120} \,  , &  0 \le \xi \le \eta \le 1
  \end{cases}
``` 
Correspondingly

```math
\tag{15}
\begin{aligned}
 & \frac{\partial V(\eta, \xi)}{\partial \xi}  = \frac{\eta (4 \eta \xi (\eta+3) - \eta^3)}{24} + \eta \, ,   
 \\
 & \frac{\partial^2 V(\eta, \xi)}{\partial \eta \partial \xi} = -\frac{\eta^3}{6} + \frac{\eta \xi (\eta + 2)}{2} + 1 \, , 
 \\
 & \frac{\partial^2 V(\eta, \xi)}{\partial \xi^2}  =  \frac{\eta^2 (\eta + 3)}{6}  \, ,  
 \\
 & \frac{\partial^3 V(\eta, \xi)}{\partial \eta \partial \xi^2} =  \frac{\eta^2}{2} +  \eta \, , 
 \\
 & \frac{\partial^4 V(\eta, \xi)}{\partial \eta^2 \partial \xi^2} =  \eta  +  1 \, , 
 \\
 &  0 \le \eta \le \xi \le 1 \, .
\end{aligned}
```  
In addition, the following formulae are required for computing the normal spline derivatives

```math
\tag{16}
\begin{aligned}
& \frac{\partial V(\eta, \xi)}{\partial \eta}  = \frac{\eta^4 - 4\xi (\eta^3 - 6) + 6 \eta \xi^2 (\eta + 2)}{24} \, ,
 \\
 & \frac{\partial^2 V(\eta, \xi)}{\partial \eta^2} = \frac{\eta ^3 - 3 \eta^2 \xi + 3 \xi^2 (\eta + 1)}{6} \, ,  
\\
 & \frac{\partial^3 V(\eta, \xi)}{\partial \eta^2 \partial \xi} = -\frac{\eta^2}{2} +  \eta \xi + \xi \, , 
 \\
 & 0 \le \eta \le \xi \le 1 \, .
\end{aligned}
``` 
Thereby we can construct a normal interpolating spline in interval ``[0, 1]``. Solving the interpolating problem in an arbitrary interval can be done by mapping the latter to ``[0,1]`` through affine change of variable. 
Define constants ``a`` and ``b`` as

```math
a =\min (x_1, s_1, t_1),  \qquad  b = \max (x_{n_1}, s_{n_2}, t_{n_3}) \, ,
```
and introduce values ``\bar x_i, \bar s_j, \bar t_k``:

```math
\bar x_i = \frac{x_i - a}{b - a}, \quad \bar s_j = \frac{s_j - a}{b - a}, \quad \bar t_k = \frac{t_k - a}{b - a} \, , 
\\
\quad  i = 1, \dots, {n_1}, \quad j = 1, \dots, n_2, \quad k = 1, \dots, n_3 \, .
```
Then original Problem (1) is transformed to

*Problem:* Given points ``0 \le \bar x_1 \lt   \bar x_2 \lt \dots \lt \bar x_{n_1} \le 1``, ``0 \le \bar s_1 \lt \bar s_2 \lt \dots \lt \bar s_{n_2} \le 1`` and  ``0 \le \bar t_1 \lt \bar t_2 \lt \dots \lt \bar t_{n_3} \le 1`` find a function ``\bar f`` such that

```math
\tag{17}
\begin{aligned}
& \bar f(\bar x_i)  =  u_i \, , \quad  i = 1, 2, \dots, n_1 \, ,
\\  
& \bar f'(\bar s_j)  =  v_j (b - a) \, , \quad  j = 1, 2, \dots, n_2 \, ,
\\  
& \bar f''(\bar t_k)  =  w_k (b - a)^2 \, , \quad  k = 1, 2, \dots, n_3 \, .
\end{aligned}
``` 
Assuming ``\bar \sigma (\bar \eta)`` is a normal spline constructed for the Problem (17), the normal spline ``\sigma (\eta)``  can be received as

```math
\sigma (\eta) = \bar \sigma \left( \frac{\eta - a}{b - a} \right),  \qquad a \le \eta \le b \, .
```

Reproducing kernel for Bessel potential space was presented in [5] and its simplified variant in [14], [3], [18], [19]. Here normal splines will be constructed in Bessel potential space ``H_\varepsilon^3(R)`` defined as

```math
   H^3_\varepsilon (R) = \left\{ f | f \in S' ,
  ( \varepsilon ^2 + | s |^2 )^{3/2}{\mathcal F} [f] \in L_2 (R) \right\} \, ,  \varepsilon \gt 0 ,
```
where ``S'  (R)`` is space of L. Schwartz tempered distributions and ``\mathcal F [f]`` is a Fourier transform of the ``f`` ([5], [3], [17]). The parameter ``\varepsilon`` may be treated as a "scaling parameter". It allows to control approximation properties of the normal spline which usually are getting better with smaller values of ``\varepsilon``, also it may be used to reduce the illconditioness of the related computational problem (in traditional theory ``\varepsilon = 1``) ([14], [20]). Space ``H^3_\varepsilon (R)`` is a Hilbert space with norm

```math
\| f \|_ {H^3_\varepsilon} =  \| (  \varepsilon ^2 + | s |^2 )^{3/2} {\mathcal F} [\varphi ] \|_{L_2} \ ,
```
it is continuously embedded in the Hölder space ``C_b^3(R)`` that consists of all functions having bounded continuous derivatives up to order ``2`` ([3]). The reproducing kernel of this space is defined up to a constant as follows ([14], [20])

```math
\tag{18}
V(\eta , \xi, \varepsilon) = \frac{1} {\varepsilon^2} \exp (-\varepsilon |\xi - \eta|)
             (3 + 3\varepsilon |\xi  - \eta| + \varepsilon ^2 |\xi - \eta| ^2 ) \, .
```
Correspondingly


```math
\tag{19}
\begin{aligned}
& \frac{\partial V(\eta , \xi, \varepsilon)}{\partial \xi}  = -\exp (-\varepsilon |\xi - \eta|)(\xi - \eta)(\varepsilon |\xi - \eta| + 1) \, ,
\\
& \frac{\partial^2 V(\eta , \xi, \varepsilon)}{\partial \eta \partial \xi} = -\exp (-\varepsilon |\xi - \eta|)(\varepsilon |\xi - \eta|(\varepsilon |\xi - \eta| - 1) - 1) \, ,  
 \\
 & \frac{\partial^2 V(\eta , \xi, \varepsilon)}{\partial \xi^2}  =  \exp (-\varepsilon |\xi - \eta|)(\varepsilon |\xi - \eta|(\varepsilon |\xi - \eta| - 1) - 1) \, ,  
 \\
 & \frac{\partial^3 V(\eta , \xi, \varepsilon)}{\partial \eta \partial \xi^2} =  \varepsilon^2  \exp (-\varepsilon |\xi - \eta|)(\xi - \eta)(\varepsilon |\xi - \eta| - 3) \, ,
 \\
 & \frac{\partial^2 V(\eta , \xi, \varepsilon)}{\partial \eta^2 \partial \xi^2} =  \varepsilon^2  \exp (-\varepsilon |\xi - \eta|)(\varepsilon |\xi - \eta|(\varepsilon |\xi - \eta| - 5) +3) \, .

\end{aligned}

```

In addition, the following formulae are required for computing the normal spline derivatives

```math
\tag{20}
\begin{aligned}
& \frac{\partial V(\eta , \xi, \varepsilon)}{\partial \eta}  = \exp (-\varepsilon |\xi - \eta|)(\xi - \eta)\varepsilon |\xi - \eta| + 1) \, ,  
\\
& \frac{\partial^2 V(\eta , \xi, \varepsilon)}{\partial \eta^2} = \exp (-\varepsilon |\xi - \eta|)(\varepsilon |\xi - \eta|(\varepsilon |\xi - \eta| - 1) - 1) \, ,  
\\
& \frac{\partial^3 V(\eta , \xi, \varepsilon)}{\partial \eta^2 \partial \xi} = -\varepsilon^2  \exp (-\varepsilon |\xi - \eta|)(\xi - \eta)(\varepsilon |\xi - \eta| - 3) \, .
\end{aligned}
``` 

In a case when there is no information of second derivative values of function ``f`` the Problem ``(1)`` is reducing to the following one:

*Problem:* Given points ``x_1 \lt  x_2 \lt \dots \lt x_{n_1}``, ``s_1 \lt s_2 \lt \dots \lt s_{n_2}`` find a function ``f`` such that

```math
\tag{21}
\begin{aligned}
& f(x_i) =  u_i \, , \quad  i = 1, 2, \dots, n_1 \, ,
\\  
& f'(s_j) =  v_j \, , \quad  j = 1, 2, \dots, n_2 \, ,
\\
& n_1 \ge 0 \, ,  \ \  n_2 \ge 0 \, .
\end{aligned}
``` 
We assume here that ``f`` is a continuously differentiable function. It can be treated as an element of Sobolev space ``W_2^2 [a, b]`` or Bessel potential space ``H_\varepsilon^2 (R)``. First space is continuously embedded in space ``C^1 [a, b]`` of functions continuous with their first derivative and the second one is continuously embedded in Hölder space ``C_b^1(R)`` of continuously differentiable functions with bounded derivative.

Reproducing kernel of Sobolev spaces ``W^2_2 [0,1]`` with norm

```math
\| f \|_{W_2^2} = \left ( \sum_{i=0}^1 (f^{(i)}(0))^2 + \int_0^1 (f^{(2)}(s))^2 ds \right )^{1/2} \, ,
```
was received in [11]:

```math
\tag{22}
V(\eta, \xi) =
  \begin{cases}
       1 + (\eta + \eta^2 / 2)\xi - \eta^3 / 6  \,  , &  0 \le \eta \le \xi \le 1  \\
       1 + (\xi + \xi^2 / 2)\eta - \xi^3 / 6 \,  , &  0 \le \xi \le \eta \le 1
    \end{cases}
``` 
Correspondingly

```math
\tag{23}
\begin{aligned}
 & \frac{\partial V(\eta, \xi)}{\partial \xi}  = \eta^2 /2 + \eta \, ,
 \\
 & \frac{\partial^2 V(\eta, \xi)}{\partial \eta \partial \xi} = \eta + 1 \, , 
 \\
 &  0 \le \eta \le \xi \le 1 \, .
\end{aligned}
``` 
In addition, the following formula is required for computing the normal spline derivative

```math
\tag{24}
\begin{aligned}
& \frac{\partial V(\eta, \xi)}{\partial \eta} = - \eta^2 /2  + \eta \xi + \xi  \, ,
 \\
 & 0 \le \eta \le \xi \le 1 \, .
\end{aligned}
``` 

Reproducing kernel for Bessel potential space ``H_\varepsilon^2(R)`` with norm 

```math
\| f \|_ {H^2_\varepsilon} =  \| (  \varepsilon ^2 + | s |^2 ) {\mathcal F} [\varphi ] \|_{L_2} \ .
```
is defined by ([14], [20]):

```math
\tag{25}
V(\eta , \xi, \varepsilon) =  \frac{1} {\varepsilon^2} \exp (-\varepsilon |\xi - \eta|)
             (1 + \varepsilon |\xi  - \eta|) \, .
``` 

Correspondingly

```math
\tag{26}
\begin{aligned}
& \frac{\partial V(\eta , \xi, \varepsilon)}{\partial \xi}  = -\exp (-\varepsilon |\xi - \eta|)(\xi - \eta) \, ,
\\
& \frac{\partial^2 V(\eta , \xi, \varepsilon)}{\partial \eta \partial \xi} = \exp (-\varepsilon |\xi - \eta|)(1 - \varepsilon |\xi - \eta|) \, .
 
\end{aligned}
 
``` 
 
In addition, the following formula is required for computing the normal spline derivative

```math
\tag{27}
\begin{aligned}
& \frac{\partial V(\eta , \xi, \varepsilon)}{\partial \eta} =  \exp (-\varepsilon |\xi - \eta|)(\xi - \eta) \, .

\end{aligned}

``` 


In a case when there is no information of function ``f`` derivatives the Problem ``(1)`` is reducing to the simplest interpolation problem:

*Problem:* Given points ``x_1 \lt  x_2 \lt \dots \lt x_{n_1}`` find a function ``f`` such that

```math
\tag{28}
\begin{aligned}
& f(x_i) =  u_i \, , \quad  i = 1, 2, \dots, n_1 \, ,
\\
& n_1 \gt 0 \, .
\end{aligned}
``` 
We assume that ``f`` is a continuous function. It can be treated as an element of Sobolev space ``W_2^1 [a, b]`` or Bessel potential space ``H_\varepsilon^1 (R)``. First space is continuously embedded in space ``C [a, b]`` of continuous functions and the second one is continuously embedded in Hölder space ``C_b^{1/2}(R)`` of continuous and bounded functions.

Reproducing kernel of Sobolev spaces ``W^2_1 [0,1]`` with norm

```math
\| f \|_{W_2^1} = \left ( (f^2(0) + \int_0^1 (f^{(1)}(s))^2 ds \right )^{1/2} \, ,
```
was received in [11]:

```math
\tag{29}
V(\eta, \xi) =
  \begin{cases}
       1 + \eta \,  , &  0 \le \eta \le \xi \le 1 \\
       1 + \xi \,  , &  0 \le \xi \le \eta \le 1 
    \end{cases}
``` 

Reproducing kernel for Bessel potential space ``H_\varepsilon^1(R)`` with norm 

```math
\| f \|_ {H^1_\varepsilon} =  \| (  \varepsilon ^2 + | s |^2)^{1/2} {\mathcal F} [\varphi ] \|_{L_2} \ .
```
is defined by ([14], [20]):

```math
\tag{30}
V(\eta , \xi, \varepsilon) = \exp (-\varepsilon |\xi - \eta|) \, .
```

The normal splines method for one-dimensional function interpolation and linear ordinary differential and integral equations was proposed in [11] and developed in [8], [9], [10]. Multidimensional normal splines method was developed for two-dimensional problem of low-range computerized tomography in [15] and applied for solving a mathematical economics problem in [12]. Further results were reported on seminars and conferences.

**References**

[1]  R. Adams, J. Fournier, Sobolev Spaces. Pure and Applied Mathematics. (2nd ed.). Boston, MA: Academic Press, 2003.

[2] D. Adams, L. Hedberg, Function spaces and potential theory. Berlin, Springer, 1996.

[3] M.S. Agranovich, Sobolev Spaces, Their Generalizations and Elliptic Problems in Smooth and Lipschitz Domains, Springer, Switzerland, 2015.

[4] N. Aronszajn, Theory of reproducing kernels, Tranzactions of the AMS.– 950 – Vol.68.

[5] N. Aronszajn, K.T. Smith, Theory of bessel potentials I, Ann.Inst.Fourier, 11,  1961.

[6] A. Balakrishnan, Applied Functional Analysis, New York, Springer-Verlag, 1976.

[7] A. Bezhaev, V. Vasilenko, Variational Theory of Splines, Springer US, 2001.

[8] V. Gorbunov, V. Petrishchev, Improvement of the normal spline collocation method for linear differential equations, Comput. Math. Math. Phys., 43:8 (2003), 1099–1108

[9] V. Gorbunov, V. Sviridov, The method of normal splines for linear DAEs on the number semi-axis. Applied Numerical Mathematics, 59(3-4), 2009, 656–670.

[10] V. Gorbunov, Extremum Problems of Measurements Data Processing, Ilim, 1990. (in Russian)

[11] V. Gorbunov, The method of normal spline collocation, USSR Computational Mathematics and Mathematical Physics,Volume 29, Issue 1, 1989, Pages 145-154.

[12] V. Gorbunov, I. Kohanovsky, K. Makedonsky, Normal splines in reconstruction of multi-dimensional dependencies. [Papers of WSEAS International Conference on Applied Mathematics, Numerical Analysis Symposium, Corfu, 2004.](http://www.wseas.us/e-library/conferences/corfu2004/papers/488-312.pdf)

[13] A. Ioffe, V. Tikhomirov, Theory of extremal problems, North-Holland, Amsterdam, 1979.

[14] I. Kohanovsky, Multidimensional Normal Splines and Problem of Physical Field Approximation, International Conference on Fourier Analysis and its Applications, Kuwait, 1998.

[15] I. Kohanovsky, Normal Splines in Computing Tomography, [Avtometriya, 1995, N 2.](https://www.iae.nsk.su/images/stories/5_Autometria/5_Archives/1995/2/84-89.pdf)

[16] P.-J. Laurent, Approximation et optimization, Paris, 1972.

[17] H. Triebel, Interpolation. Function Spaces. Differential Operators. North-Holland, Amsterdam, 1978.

[18] R. Schaback, Kernel-based Meshless Methods, Lecture Notes, Goettingen, 2011.

[19] H. Wendland, Scattered Data Approximation. Cambridge University Press, 2005.

[20] [Reproducing Kernel of Bessel Potential space.](https://igorkohan.github.io/NormalSplines.jl/stable/Reproducing-Kernel-of-Bessel-Potential-space)
